@@ -22,3 +22,11 @@ class GeneratorFileNameNotFoundException(Exception):
 
 class GeneratorFileExistsException(Exception):
     pass
+
+
+class InvalidConfigFileException(Exception):
+    pass
+
+
+class ModelWithoutAttributesException(Exception):
+    pass
